-----------------------------------------------------------------------------------------------
-- Client Lua Script for BreakingEggs
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- BreakingEggs Module Definition
-----------------------------------------------------------------------------------------------
local BreakingEggs = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------

function BreakingEggs:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
    self._playernames = {}
    self._playerWnds = {}

 

 	
    




    return o
end

function BreakingEggs:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end


-----------------------------------------------------------------------------------------------
-- BreakingEggs OnLoad
-----------------------------------------------------------------------------------------------
function BreakingEggs:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("BreakingEggs.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- BreakingEggs OnDocLoaded
-----------------------------------------------------------------------------------------------
function BreakingEggs:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "BreakingEggsForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
	    self.wndMain:Show(false, true)

		--get cell references
	    for i = 1, 15, 1 do
		    	table.insert(self._playerWnds, self.wndMain:FindChild('player'..i))
		end
		if self._playernames ~= {} then
		    --populate text fields with saved data
		    for k,v in pairs(self._playernames) do
		    	local current_wnd = self.wndMain:FindChild('player'..k)
		    	if self._playernames[k] ~= nil then
		    		current_wnd:SetText(v)
		    	end
		    end
		end



		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("eggs", "OnBreakingEggsOn", self)


		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- BreakingEggs Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

function BreakingEggs:getPlayerName(playerNum)
	local name = self.wndMain:FindChild('player'..playerNum):GetText()
	return name
end

function BreakingEggs:buildPlayerTable()
	if self._playernames == nil then
		self._playernames = {}
	end

	for i=1, 15, 1 do
		self._playernames[i] = self:getPlayerName(i)
	end
end

function BreakingEggs:announceToParty()
	-- build egg strings

	self:buildPlayerTable()

	local eggs1 = { 
		self._playernames[1].." -> ?????";
	}

	local eggs2 = {
		self._playernames[2].." -> ?????"; 
		self._playernames[3].." -> "..self._playernames[1];
	}

	local eggs3 = {
		self._playernames[4].." -> ?????";
		self._playernames[5].." -> "..self._playernames[1];
		self._playernames[6].." -> "..self._playernames[2];
		self._playernames[7].." -> "..self._playernames[3];
	}

	local eggs4 = {
		self._playernames[8].." -> ?????";
		self._playernames[9].." -> "..self._playernames[1];
		self._playernames[10].." -> "..self._playernames[2];
		self._playernames[11].." -> "..self._playernames[3];
		self._playernames[12].." -> "..self._playernames[4];
		self._playernames[13].." -> "..self._playernames[5];
		self._playernames[14].." -> "..self._playernames[6];
		self._playernames[15].." -> "..self._playernames[7];
	}

	local eggSpam = {eggs1, eggs2, eggs3, eggs4}
	local chan = self.wndMain:FindChild('spamchan'):GetText()
	for i=1, 4, 1 do
		local eggsStr = "EGG"

		ChatSystemLib.Command("/"..chan.." <------- "..2^(i-1)..eggsStr.." ------->")
		for _, playerAssignment in pairs(eggSpam[i]) do
			ChatSystemLib.Command("/"..chan.." "..playerAssignment)
		end
		eggsStr = "EGGS"
	end
end


-- on SlashCommand "/eggs"
function BreakingEggs:OnBreakingEggsOn()
	self.wndMain:Invoke() -- show the window
end

function BreakingEggs:OnSave(eLevel)
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then -- don't save per-character
		return nil
	end
	
	-- create a table to hold our data
	local saveData = {}

	saveData['version'] = 1 -- store a structure version, for later data mitigrations
	if self._players == nil then
		self._players = {}
	end

	saveData['playerNames'] = self._playernames

	return saveData
end

function BreakingEggs:OnRestore(eLevel, tData)
    if type(tData['playerNames']) == 'table' then
    	self._playernames = tData['playerNames']
    end

end

function BreakingEggs:OnCancel()
	self.wndMain:Show(false)
end

-----------------------------------------------------------------------------------------------
-- BreakingEggs Instance
-----------------------------------------------------------------------------------------------
local BreakingEggsInst = BreakingEggs:new()
BreakingEggsInst:Init()
